@@ -60,4 +60,16 @@ def galpi(n,p,o=False):
     pi = (((a+b))**2)/(4*t)
     if(k%100==0 and o):
       print(("iter"+str(k)+" {0:."+str(p)+"f}").format(pi))
-  return pi
\ No newline at end of file
+  return pi
+
+def cpi(n,p,o=False):
+	pi = 0
+	for k in range(1,n-1):
+		pi += math.sqrt(
+		1-(
+				(k/n)
+			**2)
+		)
+		if(k%100==0 and o):
+			print(("iter"+str(k)+" {0:."+str(p)+"f}").format(4/(pi/n)))
+	return (4*(pi/n))
\ No newline at end of file
